@@ -19,6 +19,12 @@ class UserExistsError(APIError):
     code = 'user_exists'
 
 
+class UserNotFoundError(APIError):
+    status_code = 404
+    detail = 'user not found'
+    code = 'user_not_found'
+
+
 class InvalidCodeError(APIError):
     status_code = 400
     detail = 'this code is invalid'
@@ -29,3 +35,9 @@ class JWTDecodError(APIError):
     status_code = 400
     detail = 'jwt decode error'
     code = 'invalid_jwt'
+
+
+class APIKeyError(APIError):
+    status_code = 403
+    detail = 'api key not valid'
+    code = 'api_key_error'
