@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.http import HttpResponse
+from rest_framework import response
 from django.contrib.auth.models import User
 from revauth.settings import api_settings
 import json
@@ -31,5 +32,4 @@ class SocialSDK:
         profile = provider.login(token, **kwargs)
         handler = self.handler_class()
         result = handler.on_login_success(profile)
-        return result
-
+        return response.Response(result, 200)
